import {useEffect, useState} from "react";
import {getRechargeDetail, RechargeWay, TopUpDetail} from "./queries/charge.ts";
import {alertError, OK} from "./utils/axios_instance.ts";
import {digitUppercase} from "./utils";

function App() {
    const queryParams = new URLSearchParams(window.location.search);

    const getQueryParam = (paramKey: string) => {
        return queryParams.get(paramKey);
    };

    const id = getQueryParam('id');
    console.log('id', id)
    const [data, setData] = useState<TopUpDetail>()

    useEffect(() => {
        const init = async () => {
            // eslint-disable-next-line @typescript-eslint/no-unused-vars
            const { code, message, topup } = await getRechargeDetail(`${id}`)
            if (code !== OK) {
                alertError(message)
                return
            }
            setData(topup)
        }
        init();
    }, [id])

    return (
        <>
            <style>
              {`
                tr {
                    height: 20px;
                    font-size: 11px;
                }
                body {
                    padding: 8px;
                    background-color: #fff;
                    width: 100%;
                    height: 100%;
                    font-family: "Microsoft YaHei", serif;
                }
                td {
                    word-break: break-all;

                }
                table {
                    display: table;
                }
            `}
            </style>
            <table border={1} cellSpacing="0" width="600px;" style={{lineHeight: '20px'}}>
              <tbody>
              <tr>
                  <td colSpan={9} style={{textAlign: 'center'}}>预付电费收款票据</td>
              </tr>
              <tr>
                  <td style={{width: '40px'}}>用户编号：</td>
                  <td style={{width: '58px'}}>{data?.tenement}</td>
                  <td style={{width: 70}}>开票日期：</td>
                  <td colSpan={2} style={{width: 80}}>{data?.toppedUpAt}</td>
                  <td></td>
                  <td>票据号：</td>
                  <td style={{width: 70}}>{data?.id}</td>
              </tr>
              <tr>
                  <td colSpan={2}>收费项目</td>
                  <td>系统编号</td>
                  <td style={{width: 60}}>商铺号</td>
                  <td style={{width: 50}}>收款方式</td>
                  <td style={{width: 55}}>收款金额</td>
                  <td style={{width: 120, borderRight: '1px solid #000'}}>备注</td>
                  <td rowSpan={3}></td>
              </tr>
              <tr>

                  {
                      data?.type === 0 ? <td colSpan={2}>正常售电</td> : (
                          data?.type === 1 ? <td colSpan={2}>冲正</td> : (
                              data?.type === 3 ? <td colSpan={2}>退费</td> : null
                          )
                      )
                  }
                  <td style={{wordBreak: 'break-all'}}>{data?.meter}</td>
                  <td>{data?.meterAddress}</td>

                  {
                      data?.paymentType ? <td>{RechargeWay[data?.paymentType]}</td> : <td></td>
                  }
                  <td>{(Number(data?.amount) || 0).toFixed(2)}</td>
                  <td>{data?.voucherNo}</td>
              </tr>
              <tr>
                  <td colSpan={2}></td>
                  <td></td>
                  <td></td>
                  <td></td>
                  <td></td>
                  <td></td>
              </tr>

              <tr>
                  <td colSpan={2}>合计金额(大写)</td>
                  <td colSpan={3}>{digitUppercase(Number((Number(data?.amount) || 0).toFixed(2)))}</td>
                  <td>小写</td>
                  <td colSpan={2}>{(Number(data?.amount) || 0).toFixed(2)}</td>
              </tr>
              <tr>
                  <td>收费员：</td>
                  <td>{data?.operatorName}</td>
                  <td>缴款人：</td>
                  <td colSpan={2}>{data?.tenementName},{data?.meterAddress}</td>
                  <td colSpan={3}>开票单位：（盖章有效）</td>
              </tr>

              <tr>
                  <td colSpan={8}>备注：请现场核对收据金额，并妥善保管收据，本收据做为缴费唯一有效凭证。</td>
              </tr>
              </tbody>
            </table>
        </>
    )
}


export default App
