import {ajaxEngine, alertError} from "../utils/axios_instance.ts";
import {AxiosResponse} from "axios";
/**
 * 用于解析来自服务端的响应体基本内容，其他响应可直接继承和扩展本接口
 */
export interface BaseResponse {
    /**
     * 用于记录服务端处理状态码
     */
    code: number;

    /**
     * 用于记录服务端处理状态信息
     */
    message: string;
}

/**
 * 对访问服务端产生的响应体进行解包处理，对于失败的访问抛出相应错误。
 * @param response Axios访问服务端产生的访问响应。
 * @returns 解包以后所需要的服务端返回的数据。
 */
export function unwrap<T extends BaseResponse>(response: AxiosResponse<T>): T {
    if (!response) {
        alertError('服务异常，请稍后重试')
        return response
    }
    if (response.status >= 300) {
        return response.data;
        // throw new NetworkError(response.status, response.data?.message || response.statusText);
    }
    return response.data;
}
/**
 * 充值记录详情
 * @param id 记录id
 */
export async function getRechargeDetail(id: string) : Promise<BaseResponse & { topup: TopUpDetail }> {
    const response = await ajaxEngine().get(`/topdetail/${id}`);
    // @ts-ignore
    return unwrap(response);
}

/**
 * 充值记录详情
 */
export interface TopUpDetail {
    /**
     * 充值账号
     */
    account: string;
    /**
     * 充值金额
     */
    amount: string;
    /**
     * 审核时间
     */
    auditedAt: string;
    /**
     * 审核员ID
     */
    auditor: null | string;
    /**
     * 审核员名称
     */
    auditorName: string;
    /**
     * 创建时间
     */
    createdAt: string;
    /**
     * 充值记录ID
     */
    id: string;
    /**
     * 表计编号
     */
    meter: string;
    /**
     * 表计地址
     */
    meterAddress: string;
    /**
     * 操作员ID
     */
    operator: string;
    /**
     * 操作员名称
     */
    operatorName: string;
    /**
     * 付款时间
     */
    paymentAt: string;
    /**
     * 充值方式，0：现金，1：银行卡，2：支付宝，3：微信，4：云闪付
     */
    paymentType: number;
    /**
     * 同步任务状态，空白表示没有对应的任务
     */
    synchronizeStatus: null | string;
    /**
     * 同步任务ID
     */
    synchronizeTask: null | string;
    /**
     * 商户ID
     */
    tenement: string;
    /**
     * 商户名称
     */
    tenementName: string;
    /**
     * 充值时间，格式：yyyy-MM-dd HH:mm:ss
     */
    toppedUpAt: string;
    /**
     * 付款凭证号
     */
    voucherNo: null | string;
    /**
     * 0充值 1冲正 2电费 3退费
     */
    type: number,
    [property: string]: any;
}

export enum RechargeWay {
    "现金支付",
    "银行卡支付",
    "支付宝支付",
    "微信支付",
    "云闪付支付",
    "公对公转账",
    "小程序充值"
}