import { message } from 'antd';
import axios, { AxiosInstance } from 'axios';

// @ts-ignore
import { MaybeMapFactory } from '@/shared/foundation';

export const alertError = (msg: string) => {
  void message.error(msg)
}

export const alertSuccess = (msg: string) => {
  void message.success(msg)
}

export const alertInfo = (msg: string) => {
  void message.info(msg)
}
let engineCache: AxiosInstance | null = null;
export const baseUrl = '/api'
/**
 * 应用中所需要使用的AJAX引擎。
 * @param forceUnauthorized 是否强制丢弃用户会话令牌信息。
 * @returns AJAX引擎实例。
 */
export const ajaxEngine: MaybeMapFactory<AxiosInstance, boolean> = () => {

  if (engineCache == null) {
    engineCache = axios.create({
      baseURL: baseUrl,
    });
    engineCache.interceptors.response.use(undefined, error => {
      switch(error?.response?.status) {
        case 403:
          alertError("登录信息已失效")
          window.location.replace("/login")
          return
        default:
      }
      if (error?.response?.data?.message || error?.response?.data) {
        message.error(error?.response?.data?.message || error?.response?.data);
      }
      return Promise.reject(error?.response?.data ?? error)}
    );
  }

  return engineCache;
};

export const OK = 200

export function getToken(): string {
  return `Bearer ${localStorage.getItem('token')}`
}


